@@ -113,11 +113,16 @@ class Manager(BaseAPI):
             sizes.append(size)
         return sizes
 
-    def get_all_images(self):
+    def get_images(self, private=False, type=None):
         """
             This function returns a list of Image object.
         """
-        data = self.get_data("images/")
+        params = {}
+        if private:
+            params['private'] = 'true'
+        if type:
+            params['type'] = type
+        data = self.get_data("images/", params=params)
         images = list()
         for jsoned in data['images']:
             image = Image(**jsoned)
@@ -125,6 +130,14 @@ class Manager(BaseAPI):
             images.append(image)
         return images
 
+    def get_all_images(self):
+        """
+            This function returns a list of Image objects containing all
+            available DigitalOcean images, both public and private.
+        """
+        images = self.get_images()
+        return images
+
     def get_image(self, image_id):
         """
             Return a Image by its ID.
@@ -133,30 +146,44 @@ class Manager(BaseAPI):
 
     def get_my_images(self):
         """
-            This function returns a list of Image object.
+            This function returns a list of Image objects representing
+            private DigitalOcean images (e.g. snapshots and backups).
         """
-        data = self.get_data("images/")
-        images = list()
-        for jsoned in data['images']:
-            if not jsoned['public']:
-                image = Image(**jsoned)
-                image.token = self.token
-                images.append(image)
+        images = self.get_images(private=True)
         return images
 
     def get_global_images(self):
         """
-            This function returns a list of Image object.
+            This function returns a list of Image objects representing
+            public DigitalOcean images (e.g. base distribution images
+            and 'One-Click' applications).
         """
-        data = self.get_data("images/")
+        data = self.get_images()
         images = list()
-        for jsoned in data['images']:
-            if jsoned['public']:
-                image = Image(**jsoned)
-                image.token = self.token
-                images.append(image)
+        for i in data:
+            if i.public:
+                i.token = self.token
+                images.append(i)
         return images
 
+    def get_distro_images(self):
+        """
+            This function returns a list of Image objects representing
+            public base distribution images.
+        """
+        images = self.get_images(type='distribution')
+        return images
+
+
+    def get_app_images(self):
+        """
+            This function returns a list of Image objectobjects representing
+            public DigitalOcean 'One-Click' application images.
+        """
+        images = self.get_images(type='application')
+        return images
+
+
     def get_all_domains(self):
         """
             This function returns a list of Domain object.
